@@ -36,6 +36,8 @@ cvar_t *cl_http_filelists;
 cvar_t *cl_http_proxy;
 cvar_t *cl_http_max_connections;
 cvar_t *cl_http_show_dw_progress;
+cvar_t *cl_http_bw_limit_rate;
+cvar_t *cl_http_bw_limit_tmout;
 
 dlquirks_t dlquirks = { .error = false, .filelist = true, .gamedir = {'\0'} };
 
@@ -217,7 +219,7 @@ static qboolean CL_RemoveFromQueue(dlqueue_t *entry)
 static void CL_StartHTTPDownload (dlqueue_t *entry, dlhandle_t *dl)
 {
 	char tempFile[MAX_OSPATH];
-	char escapedFilePath[MAX_QPATH*4];
+	char escapedFilePath[MAX_QPATH*4] = {0};
 
 	size_t len = strlen(entry->quakePath);
 
@@ -290,6 +292,9 @@ static void CL_StartHTTPDownload (dlqueue_t *entry, dlhandle_t *dl)
 	}
 
 	qcurl_easy_setopt(dl->curl, CURLOPT_PROXY, cl_http_proxy->string);
+	qcurl_easy_setopt(dl->curl, CURLOPT_LOW_SPEED_TIME, (long)cl_http_bw_limit_tmout->value);
+	qcurl_easy_setopt(dl->curl, CURLOPT_LOW_SPEED_LIMIT, (long)cl_http_bw_limit_rate->value);
+	qcurl_easy_setopt(dl->curl, CURLOPT_CONNECTTIMEOUT, 30);
 	qcurl_easy_setopt(dl->curl, CURLOPT_FOLLOWLOCATION, 1);
 	qcurl_easy_setopt(dl->curl, CURLOPT_MAXREDIRS, 5);
 	qcurl_easy_setopt(dl->curl, CURLOPT_NOPROGRESS, (cl_http_show_dw_progress->value != 1.0));
