@@ -294,13 +294,9 @@ extern	cvar_t	*cl_shownet;
 extern	cvar_t	*cl_showmiss;
 extern	cvar_t	*cl_showclamp;
 extern	cvar_t	*lookstrafe;
-extern	cvar_t	*sensitivity;
-extern	cvar_t	*joy_expo;
-extern	cvar_t	*joy_yawsensitivity;
-extern	cvar_t	*joy_pitchsensitivity;
-extern	cvar_t	*joy_forwardsensitivity;
-extern	cvar_t	*joy_sidesensitivity;
-extern	cvar_t	*joy_upsensitivity;
+extern	cvar_t	*joy_layout;
+extern	cvar_t	*gyro_mode;
+extern	cvar_t	*gyro_turning_axis;
 extern	cvar_t	*m_pitch;
 extern	cvar_t	*m_yaw;
 extern	cvar_t	*m_forward;
