@@ -285,10 +285,8 @@ void Key_ReadConsoleHistory();
 void Key_WriteConsoleHistory();
 void Key_SetBinding(int keynum, char *binding);
 void Key_MarkAllUp(void);
-void Haptic_Feedback(char *name, int effect_volume, int effect_duration,
-				   int effect_begin, int effect_end,
-				   int effect_attack, int effect_fade,
-				   int effect_x, int effect_y, int effect_z);
+void Controller_Rumble(const char *name, vec3_t source, qboolean from_player,
+				unsigned int duration, unsigned short int volume);
 int Key_GetMenuKey(int key);
 
 #endif
