@@ -32,8 +32,8 @@
 Mod_DecompressVis
 ===================
 */
-byte *
-Mod_DecompressVis(byte *in, int row)
+const byte *
+Mod_DecompressVis(const byte *in, int row)
 {
 	YQ2_ALIGNAS_TYPE(int) static byte decompressed[MAX_MAP_LEAFS / 8];
 	int c;
