@@ -214,6 +214,7 @@ R_TextureMode(char *string)
 	}
 
 	const char* nolerplist = gl_nolerp_list->string;
+	const char* lerplist = r_lerp_list->string;
 	qboolean unfiltered2D = r_2D_unfiltered->value != 0;
 
 	/* change all the existing mipmap texture objects */
@@ -221,7 +222,12 @@ R_TextureMode(char *string)
 	{
 		qboolean nolerp = false;
 		/* r_2D_unfiltered and r_nolerp_list allow rendering stuff unfiltered even if gl_filter_* is filtered */
-		if ( (unfiltered2D && glt->type == it_pic) || (nolerplist != NULL && strstr(nolerplist, glt->name) != NULL) )
+		if (unfiltered2D && glt->type == it_pic)
+		{
+			// exception to that exception: stuff on the r_lerp_list
+			nolerp = (lerplist== NULL) || (strstr(lerplist, glt->name) == NULL);
+		}
+		else if(nolerplist != NULL && strstr(nolerplist, glt->name) != NULL)
 		{
 			nolerp = true;
 		}
@@ -353,9 +359,10 @@ R_ImageList_f(void)
 				break;
 		}
 
-		R_Printf(PRINT_ALL, " %3i %3i %s: %s %s\n",
+		R_Printf(PRINT_ALL, " %3i %3i %s: %s (%dx%d) %s\n",
 				image->upload_width, image->upload_height,
-				palstrings[image->paletted], image->name, in_use);
+				palstrings[image->paletted], image->name,
+				image->width, image->height, in_use);
 	}
 
 	R_Printf(PRINT_ALL,
@@ -858,9 +865,11 @@ R_LoadPic(char *name, byte *pic, int width, int realwidth,
 	qboolean nolerp = false;
 	if (r_2D_unfiltered->value && type == it_pic)
 	{
-		nolerp = true;
+		// if r_2D_unfiltered is true(ish), nolerp should usually be true,
+		// *unless* the texture is on the r_lerp_list
+		nolerp = (r_lerp_list->string == NULL) || (strstr(r_lerp_list->string, name) == NULL);
 	}
-	else if(gl_nolerp_list != NULL && gl_nolerp_list->string != NULL)
+	else if (gl_nolerp_list != NULL && gl_nolerp_list->string != NULL)
 	{
 		nolerp = strstr(gl_nolerp_list->string, name) != NULL;
 	}
@@ -951,9 +960,24 @@ R_LoadPic(char *name, byte *pic, int width, int realwidth,
 			// resize 8bit images only when we forced such logic
 			if (r_scale8bittextures->value)
 			{
-				byte *image_converted = malloc(width * height * 4);
-				scale2x(pic, image_converted, width, height);
-				image->has_alpha = R_Upload8(image_converted, width * 2, height * 2,
+				byte *image_converted;
+				int scale = 2;
+
+				// scale 3 times if lerp image
+				if (!nolerp && (vid.height >= 240 * 3))
+					scale = 3;
+
+				image_converted = malloc(width * height * scale * scale);
+				if (!image_converted)
+					return NULL;
+
+				if (scale == 3) {
+					scale3x(pic, image_converted, width, height);
+				} else {
+					scale2x(pic, image_converted, width, height);
+				}
+
+				image->has_alpha = R_Upload8(image_converted, width * scale, height * scale,
 							(image->type != it_pic && image->type != it_sky),
 							image->type == it_sky);
 				free(image_converted);
