@@ -219,7 +219,6 @@ R_RecursiveLightPoint(mnode_t *node, vec3_t start, vec3_t end)
 	byte *lightmap;
 	int maps;
 	int r;
-	vec3_t	scale;
 
 	if (node->contents != -1)
 	{
@@ -303,17 +302,20 @@ R_RecursiveLightPoint(mnode_t *node, vec3_t start, vec3_t end)
 		for (maps = 0; maps < MAXLIGHTMAPS && surf->styles[maps] != 255;
 			 maps++)
 		{
+			const float *rgb;
 			int j;
 
+			rgb = r_newrefdef.lightstyles[surf->styles[maps]].rgb;
+
+			/* Apply light level to models */
 			for (j = 0; j < 3; j++)
 			{
-				scale[j] = r_modulate->value *
-						r_newrefdef.lightstyles[surf->styles[maps]].rgb[j];
+				float	scale;
+
+				scale = rgb[j] * r_modulate->value;
+				pointcolor[j] += lightmap[j] * scale * (1.0 / 255);
 			}
 
-			pointcolor[0] += lightmap[0] * scale[0] * (1.0 / 255);
-			pointcolor[1] += lightmap[1] * scale[1] * (1.0 / 255);
-			pointcolor[2] += lightmap[2] * scale[2] * (1.0 / 255);
 			lightmap += 3 * ((surf->extents[0] >> 4) + 1) *
 						((surf->extents[1] >> 4) + 1);
 		}
