@@ -195,7 +195,9 @@ extern cvar_t *r_retexturing;
 extern cvar_t *r_scale8bittextures;
 
 extern cvar_t *gl_nolerp_list;
+extern cvar_t *r_lerp_list;
 extern cvar_t *r_2D_unfiltered;
+extern cvar_t *r_videos_unfiltered;
 
 extern cvar_t *gl_lightmap;
 extern cvar_t *gl_shadows;
@@ -302,7 +304,7 @@ int Scrap_AllocBlock(int w, int h, int *x, int *y);
 /* GL extension emulation functions */
 void R_DrawParticles2(int n,
 		const particle_t particles[],
-		const unsigned colortable[768]);
+		const unsigned *colortable);
 
 /*
  * GL config stuff
