@@ -88,6 +88,7 @@ GL3_TextureMode(char *string)
 	gl3image_t *glt;
 
 	const char* nolerplist = gl_nolerp_list->string;
+	const char* lerplist = r_lerp_list->string;
 	qboolean unfiltered2D = r_2D_unfiltered->value != 0;
 
 	/* change all the existing texture objects */
@@ -95,7 +96,12 @@ GL3_TextureMode(char *string)
 	{
 		qboolean nolerp = false;
 		/* r_2D_unfiltered and gl_nolerp_list allow rendering stuff unfiltered even if gl_filter_* is filtered */
-		if ( (unfiltered2D && glt->type == it_pic) || (nolerplist != NULL && strstr(nolerplist, glt->name) != NULL) )
+		if (unfiltered2D && glt->type == it_pic)
+		{
+			// exception to that exception: stuff on the r_lerp_list
+			nolerp = (lerplist== NULL) || (strstr(lerplist, glt->name) == NULL);
+		}
+		else if(nolerplist != NULL && strstr(nolerplist, glt->name) != NULL)
 		{
 			nolerp = true;
 		}
@@ -185,15 +191,11 @@ GL3_Upload32(unsigned *data, int width, int height, qboolean mipmap)
 {
 	qboolean res;
 
-	int samples;
-	int i, c;
-	byte *scan;
-	int comp;
-
-	c = width * height;
-	scan = ((byte *)data) + 3;
-	samples = gl3_solid_format;
-	comp = gl3_tex_solid_format;
+	int i;
+	int c = width * height;
+	byte *scan = ((byte *)data) + 3;
+	int comp = gl3_tex_solid_format;
+	int samples = gl3_solid_format;
 
 	for (i = 0; i < c; i++, scan += 4)
 	{
@@ -383,7 +385,9 @@ GL3_LoadPic(char *name, byte *pic, int width, int realwidth,
 	qboolean nolerp = false;
 	if (r_2D_unfiltered->value && type == it_pic)
 	{
-		nolerp = true;
+		// if r_2D_unfiltered is true(ish), nolerp should usually be true,
+		// *unless* the texture is on the r_lerp_list
+		nolerp = (r_lerp_list->string == NULL) || (strstr(r_lerp_list->string, name) == NULL);
 	}
 	else if (gl_nolerp_list != NULL && gl_nolerp_list->string != NULL)
 	{
@@ -442,9 +446,24 @@ GL3_LoadPic(char *name, byte *pic, int width, int realwidth,
 		// resize 8bit images only when we forced such logic
 		if (r_scale8bittextures->value)
 		{
-			byte *image_converted = malloc(width * height * 4);
-			scale2x(pic, image_converted, width, height);
-			image->has_alpha = GL3_Upload8(image_converted, width * 2, height * 2,
+			byte *image_converted;
+			int scale = 2;
+
+			// scale 3 times if lerp image
+			if (!nolerp && (vid.height >= 240 * 3))
+				scale = 3;
+
+			image_converted = malloc(width * height * scale * scale);
+			if (!image_converted)
+				return NULL;
+
+			if (scale == 3) {
+				scale3x(pic, image_converted, width, height);
+			} else {
+				scale2x(pic, image_converted, width, height);
+			}
+
+			image->has_alpha = GL3_Upload8(image_converted, width * scale, height * scale,
 						(image->type != it_pic && image->type != it_sky),
 						image->type == it_sky);
 			free(image_converted);
