@@ -26,6 +26,7 @@
  */
 
 #include <assert.h>
+#include <stddef.h> // ofsetof()
 
 #include "header/local.h"
 
@@ -332,7 +333,7 @@ UpdateLMscales(const hmm_vec4 lmScales[MAX_LIGHTMAPS_PER_SURFACE], gl3ShaderInfo
 
 	if(hasChanged)
 	{
-		glUniform4fv(si->uniLmScales, MAX_LIGHTMAPS_PER_SURFACE, si->lmScales[0].Elements);
+		glUniform4fv(si->uniLmScalesOrTime, MAX_LIGHTMAPS_PER_SURFACE, si->lmScales[0].Elements);
 	}
 }
 
