@@ -40,6 +40,7 @@ static int	swap_current = 0;
 espan_t		*vid_polygon_spans = NULL;
 pixel_t		*vid_colormap = NULL;
 pixel_t		*vid_alphamap = NULL;
+light_t		vid_lightthreshold = 0;
 static int	vid_minu, vid_minv, vid_maxu, vid_maxv;
 static int	vid_zminu, vid_zminv, vid_zmaxu, vid_zmaxv;
 
@@ -51,7 +52,7 @@ static qboolean	palette_changed;
 
 refimport_t	ri;
 
-static unsigned	d_8to24table[256];
+byte		d_8to24table[256 * 4];
 
 char		skyname[MAX_QPATH];
 vec3_t		skyaxis;
@@ -134,6 +135,8 @@ float	se_time1, se_time2, de_time1, de_time2;
 cvar_t	*r_lefthand;
 cvar_t	*r_gunfov;
 cvar_t	*r_farsee;
+cvar_t	*r_lightmap;
+cvar_t	*r_colorlight;
 static cvar_t	*sw_aliasstats;
 cvar_t	*sw_clearcolor;
 cvar_t	*sw_drawflat;
@@ -394,6 +397,8 @@ R_RegisterVariables (void)
 	r_lefthand = ri.Cvar_Get( "hand", "0", CVAR_USERINFO | CVAR_ARCHIVE );
 	r_gunfov = ri.Cvar_Get( "r_gunfov", "80", CVAR_ARCHIVE );
 	r_farsee = ri.Cvar_Get("r_farsee", "0", CVAR_LATCH | CVAR_ARCHIVE);
+	r_lightmap = ri.Cvar_Get("r_lightmap", "0", 0);
+	r_colorlight = ri.Cvar_Get("sw_colorlight", "0", CVAR_ARCHIVE);
 	r_speeds = ri.Cvar_Get ("r_speeds", "0", 0);
 	r_fullbright = ri.Cvar_Get ("r_fullbright", "0", 0);
 	r_drawentities = ri.Cvar_Get ("r_drawentities", "1", 0);
@@ -508,6 +513,7 @@ RE_Shutdown (void)
 		free (vid_colormap);
 		vid_colormap = NULL;
 	}
+
 	R_UnRegister ();
 	Mod_FreeAll ();
 	R_ShutdownImages ();
@@ -1036,8 +1042,8 @@ RotatedBBox (const vec3_t mins, const vec3_t maxs, vec3_t angles, vec3_t tmins,
 
 	for (i=0 ; i<3 ; i++)
 	{
-		tmins[i] = INT_MAX; // Set maximum values for world range
-		tmaxs[i] = INT_MIN;  // Set minimal values for world range
+		tmins[i] = (vec_t)INT_MAX; // Set maximum values for world range
+		tmaxs[i] = (vec_t)INT_MIN;  // Set minimal values for world range
 	}
 
 	AngleVectors (angles, forward, right, up);
@@ -1228,7 +1234,7 @@ R_CalcPalette (void)
 		if (modified)
 		{	// set back to default
 			modified = false;
-			R_GammaCorrectAndSetPalette( ( const unsigned char * ) d_8to24table );
+			R_GammaCorrectAndSetPalette( d_8to24table );
 			return;
 		}
 		return;
@@ -1244,7 +1250,7 @@ R_CalcPalette (void)
 
 	one_minus_alpha = (1.0 - alpha);
 
-	in = (byte *)d_8to24table;
+	in = d_8to24table;
 	out = palette[0];
 	for (i=0 ; i<256 ; i++, in+=4, out+=4)
 	{
@@ -1280,7 +1286,7 @@ R_SetLightLevel (const entity_t *currententity)
 }
 
 static int
-VectorCompareRound(vec3_t v1, vec3_t v2)
+VectorCompareRound(const vec3_t v1, const vec3_t v2)
 {
 	if ((int)(v1[0] - v2[0]) || (int)(v1[1] - v2[1]) || (int)(v1[2] - v2[2]))
 	{
@@ -1341,7 +1347,7 @@ RE_RenderFrame (refdef_t *fd)
 	// For each dlight_t* passed via r_newrefdef.dlights, mark polygons affected by a light.
 	R_PushDlights (r_worldmodel);
 
-	// TODO: rearange code same as in GL*_DrawWorld?
+	// TODO: rearrange code same as in GL*_DrawWorld?
 	/* auto cycle the world frame for texture animation */
 	memset(&ent, 0, sizeof(ent));
 	ent.frame = (int)(r_newrefdef.time * 2);
@@ -1437,7 +1443,7 @@ R_InitGraphics( int width, int height )
 
 	R_InitCaches();
 
-	R_GammaCorrectAndSetPalette((const unsigned char *)d_8to24table);
+	R_GammaCorrectAndSetPalette(d_8to24table);
 }
 
 static rserr_t	SWimp_SetMode(int *pwidth, int *pheight, int mode, int fullscreen);
@@ -1464,7 +1470,7 @@ RE_BeginFrame( float camera_separation )
 	if ( vid_gamma->modified || sw_overbrightbits->modified )
 	{
 		Draw_BuildGammaTable();
-		R_GammaCorrectAndSetPalette((const unsigned char * )d_8to24table);
+		R_GammaCorrectAndSetPalette(d_8to24table);
 		// we need redraw everything
 		VID_WholeDamageBuffer();
 		// and backbuffer should be zeroed
@@ -1580,13 +1586,12 @@ R_GammaCorrectAndSetPalette( const unsigned char *palette )
 static void
 RE_SetPalette(const unsigned char *palette)
 {
-	byte palette32[1024];
-
 	// clear screen to black to avoid any palette flash
 	RE_CleanFrame();
 
 	if (palette)
 	{
+		byte palette32[1024];
 		int i;
 
 		for ( i = 0; i < 256; i++ )
@@ -1601,7 +1606,7 @@ RE_SetPalette(const unsigned char *palette)
 	}
 	else
 	{
-		R_GammaCorrectAndSetPalette((const unsigned char *)d_8to24table);
+		R_GammaCorrectAndSetPalette(d_8to24table);
 	}
 }
 
@@ -1726,7 +1731,7 @@ RE_SetSky (char *name, float rotate, vec3_t axis)
 	int		i;
 	char	pathname[MAX_QPATH];
 
-	strncpy (skyname, name, sizeof(skyname)-1);
+	Q_strlcpy (skyname, name, sizeof(skyname));
 	VectorCopy (axis, skyaxis);
 
 	for (i=0 ; i<6 ; i++)
@@ -1752,13 +1757,13 @@ Draw_GetPalette (void)
 	byte	*pal, *out;
 	int		i;
 
-	// get the palette and colormap
+	/* get the palette and colormap */
 	LoadPCX ("pics/colormap.pcx", &vid_colormap, &pal, NULL, NULL);
 	if (!vid_colormap)
 		ri.Sys_Error (ERR_FATAL, "Couldn't load pics/colormap.pcx");
 	vid_alphamap = vid_colormap + 64*256;
 
-	out = (byte *)d_8to24table;
+	out = d_8to24table;
 	for (i=0 ; i<256 ; i++, out+=4)
 	{
 		int r, g, b;
@@ -2292,7 +2297,7 @@ SWimp_SetMode(int *pwidth, int *pheight, int mode, int fullscreen )
 
 	if ((mode >= 0) && !ri.Vid_GetModeInfo( pwidth, pheight, mode ) )
 	{
-		R_Printf( PRINT_ALL, " invalid mode\n" );
+		R_Printf(PRINT_ALL, " invalid mode\n");
 		return rserr_invalid_mode;
 	}
 
@@ -2301,7 +2306,7 @@ SWimp_SetMode(int *pwidth, int *pheight, int mode, int fullscreen )
 	{
 		if(!ri.GLimp_GetDesktopMode(pwidth, pheight))
 		{
-			R_Printf( PRINT_ALL, " can't detect mode\n" );
+			R_Printf(PRINT_ALL, " can't detect mode\n");
 			return rserr_invalid_mode;
 		}
 	}
@@ -2408,7 +2413,7 @@ SWimp_CreateRender(int width, int height)
 
 	memset(sw_state.currentpalette, 0, sizeof(sw_state.currentpalette));
 
-	R_GammaCorrectAndSetPalette( ( const unsigned char * ) d_8to24table );
+	R_GammaCorrectAndSetPalette( d_8to24table );
 }
 
 // this is only here so the functions in q_shared.c and q_shwin.c can link
