@@ -26,41 +26,42 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 typedef struct {
 	int	isflattop;
 	int	numleftedges;
-	int	*pleftedgevert0;
-	int	*pleftedgevert1;
-	int	*pleftedgevert2;
+	compactvert_t	*pleftedgevert0;
+	compactvert_t	*pleftedgevert1;
+	compactvert_t	*pleftedgevert2;
 	int	numrightedges;
-	int	*prightedgevert0;
-	int	*prightedgevert1;
-	int	*prightedgevert2;
+	compactvert_t	*prightedgevert0;
+	compactvert_t	*prightedgevert1;
+	compactvert_t	*prightedgevert2;
 } edgetable;
 
 static int	ubasestep, errorterm, erroradjustup, erroradjustdown;
 
-static int	r_p0[6], r_p1[6], r_p2[6];
+static compactvert_t r_p0, r_p1, r_p2;
 
 static int	d_xdenom;
 
 static edgetable *pedgetable;
 
 static edgetable edgetables[12] = {
-	{0, 1, r_p0, r_p2, NULL, 2, r_p0, r_p1, r_p2},
-	{0, 2, r_p1, r_p0, r_p2, 1, r_p1, r_p2, NULL},
-	{1, 1, r_p0, r_p2, NULL, 1, r_p1, r_p2, NULL},
-	{0, 1, r_p1, r_p0, NULL, 2, r_p1, r_p2, r_p0},
-	{0, 2, r_p0, r_p2, r_p1, 1, r_p0, r_p1, NULL},
-	{0, 1, r_p2, r_p1, NULL, 1, r_p2, r_p0, NULL},
-	{0, 1, r_p2, r_p1, NULL, 2, r_p2, r_p0, r_p1},
-	{0, 2, r_p2, r_p1, r_p0, 1, r_p2, r_p0, NULL},
-	{0, 1, r_p1, r_p0, NULL, 1, r_p1, r_p2, NULL},
-	{1, 1, r_p2, r_p1, NULL, 1, r_p0, r_p1, NULL},
-	{1, 1, r_p1, r_p0, NULL, 1, r_p2, r_p0, NULL},
-	{0, 1, r_p0, r_p2, NULL, 1, r_p0, r_p1, NULL},
+	{0, 1, &r_p0, &r_p2, NULL, 2, &r_p0, &r_p1, &r_p2},
+	{0, 2, &r_p1, &r_p0, &r_p2, 1, &r_p1, &r_p2, NULL},
+	{1, 1, &r_p0, &r_p2, NULL, 1, &r_p1, &r_p2, NULL},
+	{0, 1, &r_p1, &r_p0, NULL, 2, &r_p1, &r_p2, &r_p0},
+	{0, 2, &r_p0, &r_p2, &r_p1, 1, &r_p0, &r_p1, NULL},
+	{0, 1, &r_p2, &r_p1, NULL, 1, &r_p2, &r_p0, NULL},
+	{0, 1, &r_p2, &r_p1, NULL, 2, &r_p2, &r_p0, &r_p1},
+	{0, 2, &r_p2, &r_p1, &r_p0, 1, &r_p2, &r_p0, NULL},
+	{0, 1, &r_p1, &r_p0, NULL, 1, &r_p1, &r_p2, NULL},
+	{1, 1, &r_p2, &r_p1, NULL, 1, &r_p0, &r_p1, NULL},
+	{1, 1, &r_p1, &r_p0, NULL, 1, &r_p2, &r_p0, NULL},
+	{0, 1, &r_p0, &r_p2, NULL, 1, &r_p0, &r_p1, NULL},
 };
 
 // FIXME: some of these can become statics
-static int	a_sstepxfrac, a_tstepxfrac, r_lstepx, a_ststepxwhole;
-static int	r_sstepx, r_tstepx, r_lstepy, r_sstepy, r_tstepy;
+static int	a_sstepxfrac, a_tstepxfrac, a_ststepxwhole;
+static int	r_sstepx, r_tstepx, r_sstepy, r_tstepy;
+static light3_t	r_lstepx, r_lstepy;
 static zvalue_t	r_zistepx, r_zistepy;
 static int	d_aspancount;
 
@@ -68,17 +69,18 @@ static spanpackage_t	*d_pedgespanpackage;
 
 spanpackage_t	*triangle_spans, *triangles_max;
 
-static int	d_sfrac, d_tfrac, d_light;
+static int	d_sfrac, d_tfrac;
+static light3_t d_light;
 static zvalue_t	d_zi;
 static int	d_ptexextrastep, d_sfracextrastep;
-static int	d_tfracextrastep, d_lightextrastep;
-static int	d_lightbasestep, d_ptexbasestep;
+static int	d_tfracextrastep, d_ptexbasestep;
+static light3_t	d_lightbasestep, d_lightextrastep;
 static int	d_sfracbasestep, d_tfracbasestep;
 static zvalue_t	d_ziextrastep, d_zibasestep;
 
 static byte	*skintable[MAX_LBM_HEIGHT];
 int		skinwidth;
-static byte	*skinstart;
+static pixel_t	*skinstart;
 
 void	(*d_pdrawspans)(const entity_t *currententity, spanpackage_t *pspanpackage);
 
@@ -169,14 +171,14 @@ R_DrawTriangle(const entity_t *currententity, const finalvert_t *a, const finalv
 			   ( a->v[0] - b->v[0] ) * ( a->v[1] - c->v[1] );
 	*/
 
-	dv0_ab = a->u - b->u;
-	dv1_ab = a->v - b->v;
+	dv0_ab = a->cv.u - b->cv.u;
+	dv1_ab = a->cv.v - b->cv.v;
 
 	if ( !( dv0_ab | dv1_ab ) )
 		return;
 
-	dv0_ac = a->u - c->u;
-	dv1_ac = a->v - c->v;
+	dv0_ac = a->cv.u - c->cv.u;
+	dv1_ac = a->cv.v - c->cv.v;
 
 	if ( !( dv0_ac | dv1_ac ) )
 		return;
@@ -185,26 +187,9 @@ R_DrawTriangle(const entity_t *currententity, const finalvert_t *a, const finalv
 
 	if ( d_xdenom < 0 )
 	{
-		r_p0[0] = a->u;	// u
-		r_p0[1] = a->v;	// v
-		r_p0[2] = a->s;	// s
-		r_p0[3] = a->t;	// t
-		r_p0[4] = a->l;	// light
-		r_p0[5] = a->zi;	// iz
-
-		r_p1[0] = b->u;
-		r_p1[1] = b->v;
-		r_p1[2] = b->s;
-		r_p1[3] = b->t;
-		r_p1[4] = b->l;
-		r_p1[5] = b->zi;
-
-		r_p2[0] = c->u;
-		r_p2[1] = c->v;
-		r_p2[2] = c->s;
-		r_p2[3] = c->t;
-		r_p2[4] = c->l;
-		r_p2[5] = c->zi;
+		memcpy(&r_p0, &a->cv, sizeof(compactvert_t));
+		memcpy(&r_p1, &b->cv, sizeof(compactvert_t));
+		memcpy(&r_p2, &c->cv, sizeof(compactvert_t));
 
 		R_PolysetSetEdgeTable ();
 		R_RasterizeAliasPolySmooth(currententity);
@@ -213,7 +198,7 @@ R_DrawTriangle(const entity_t *currententity, const finalvert_t *a, const finalv
 
 static void
 R_PushEdgesSpan(int u, int v, int count,
-		pixel_t* d_ptex, int d_sfrac, int d_tfrac, int d_light, zvalue_t d_zi)
+		pixel_t* d_ptex, int d_sfrac, int d_tfrac, light3_t d_light, zvalue_t d_zi)
 {
 	if (d_pedgespanpackage >= triangles_max)
 	{
@@ -231,7 +216,7 @@ R_PushEdgesSpan(int u, int v, int count,
 	d_pedgespanpackage->tfrac = d_tfrac;
 
 	// FIXME: need to clamp l, s, t, at both ends?
-	d_pedgespanpackage->light = d_light;
+	memcpy(d_pedgespanpackage->light, d_light, sizeof(light3_t));
 	d_pedgespanpackage->zi = d_zi;
 
 	d_pedgespanpackage++;
@@ -257,6 +242,8 @@ R_PolysetScanLeftEdge_C(int height, pixel_t *d_ptex, int u, int v)
 		errorterm += erroradjustup;
 		if (errorterm >= 0)
 		{
+			int i;
+
 			// addtional step for compensate error
 			u ++;
 			d_aspancount ++;
@@ -272,12 +259,17 @@ R_PolysetScanLeftEdge_C(int height, pixel_t *d_ptex, int u, int v)
 				d_ptex += r_affinetridesc.skinwidth;
 				d_tfrac &= 0xFFFF;
 			}
-			d_light += d_lightextrastep;
+
+			for(i=0; i<3; i++)
+				d_light[i] += d_lightextrastep[i];
+
 			d_zi += d_ziextrastep;
 			errorterm -= erroradjustdown;
 		}
 		else
 		{
+			int i;
+
 			d_ptex += d_ptexbasestep;
 			d_sfrac += d_sfracbasestep;
 			d_ptex += d_sfrac >> SHIFT16XYZ;
@@ -288,7 +280,10 @@ R_PolysetScanLeftEdge_C(int height, pixel_t *d_ptex, int u, int v)
 				d_ptex += r_affinetridesc.skinwidth;
 				d_tfrac &= 0xFFFF;
 			}
-			d_light += d_lightbasestep;
+
+			for(i=0; i<3; i++)
+				d_light[i] += d_lightbasestep[i];
+
 			d_zi += d_zibasestep;
 		}
 	} while (--height);
@@ -371,11 +366,12 @@ R_PolysetCalcGradients (int skinwidth)
 {
 	float	xstepdenominv, ystepdenominv, t0, t1;
 	float	p01_minus_p21, p11_minus_p21, p00_minus_p20, p10_minus_p20;
+	int i;
 
-	p00_minus_p20 = r_p0[0] - r_p2[0];
-	p01_minus_p21 = r_p0[1] - r_p2[1];
-	p10_minus_p20 = r_p1[0] - r_p2[0];
-	p11_minus_p21 = r_p1[1] - r_p2[1];
+	p00_minus_p20 = r_p0.u - r_p2.u;
+	p01_minus_p21 = r_p0.v - r_p2.v;
+	p10_minus_p20 = r_p1.u - r_p2.u;
+	p11_minus_p21 = r_p1.v - r_p2.v;
 
 	xstepdenominv = 1.0 / (float)d_xdenom;
 
@@ -384,29 +380,32 @@ R_PolysetCalcGradients (int skinwidth)
 	// ceil () for light so positive steps are exaggerated, negative steps
 	// diminished,  pushing us away from underflow toward overflow. Underflow is
 	// very visible, overflow is very unlikely, because of ambient lighting
-	t0 = r_p0[4] - r_p2[4];
-	t1 = r_p1[4] - r_p2[4];
-	r_lstepx = (int)
-			ceil((t1 * p01_minus_p21 - t0 * p11_minus_p21) * xstepdenominv);
-	r_lstepy = (int)
-			ceil((t1 * p00_minus_p20 - t0 * p10_minus_p20) * ystepdenominv);
+	for (i=0; i<3; i++)
+	{
+		t0 = r_p0.l[i] - r_p2.l[i];
+		t1 = r_p1.l[i] - r_p2.l[i];
+		r_lstepx[i] = (int)
+				ceil((t1 * p01_minus_p21 - t0 * p11_minus_p21) * xstepdenominv);
+		r_lstepy[i] = (int)
+				ceil((t1 * p00_minus_p20 - t0 * p10_minus_p20) * ystepdenominv);
+	}
 
-	t0 = r_p0[2] - r_p2[2];
-	t1 = r_p1[2] - r_p2[2];
+	t0 = r_p0.s - r_p2.s;
+	t1 = r_p1.s - r_p2.s;
 	r_sstepx = (int)((t1 * p01_minus_p21 - t0 * p11_minus_p21) *
 			xstepdenominv);
 	r_sstepy = (int)((t1 * p00_minus_p20 - t0* p10_minus_p20) *
 			ystepdenominv);
 
-	t0 = r_p0[3] - r_p2[3];
-	t1 = r_p1[3] - r_p2[3];
+	t0 = r_p0.t - r_p2.t;
+	t1 = r_p1.t - r_p2.t;
 	r_tstepx = (int)((t1 * p01_minus_p21 - t0 * p11_minus_p21) *
 			xstepdenominv);
 	r_tstepy = (int)((t1 * p00_minus_p20 - t0 * p10_minus_p20) *
 			ystepdenominv);
 
-	t0 = r_p0[5] - r_p2[5];
-	t1 = r_p1[5] - r_p2[5];
+	t0 = r_p0.zi - r_p2.zi;
+	t1 = r_p1.zi - r_p2.zi;
 	r_zistepx = (int)((t1 * p01_minus_p21 - t0 * p11_minus_p21) *
 			xstepdenominv);
 	r_zistepy = (int)((t1 * p00_minus_p20 - t0 * p10_minus_p20) *
@@ -429,10 +428,10 @@ R_PolysetDrawSpans8
 void
 R_PolysetDrawSpans8_33(const entity_t *currententity, spanpackage_t *pspanpackage)
 {
-	byte		*lpdest;
-	byte		*lptex;
+	pixel_t		*lpdest;
+	pixel_t		*lptex;
 	int		lsfrac, ltfrac;
-	int		llight;
+	light3_t	llight;
 	zvalue_t	lzi;
 	zvalue_t	*lpz;
 
@@ -461,21 +460,24 @@ R_PolysetDrawSpans8_33(const entity_t *currententity, spanpackage_t *pspanpackag
 			lptex = pspanpackage->ptex;
 			lsfrac = pspanpackage->sfrac;
 			ltfrac = pspanpackage->tfrac;
-			llight = pspanpackage->light;
+			memcpy(llight, pspanpackage->light, sizeof(light3_t));
 			lzi = pspanpackage->zi;
 
 			do
 			{
+				int i;
+
 				if ((lzi >> SHIFT16XYZ) >= *lpz)
 				{
-					int temp = vid_colormap[*lptex + ( llight & 0xFF00 )];
+					int temp = R_ApplyLight(*lptex, llight);
 
-					*lpdest = vid_alphamap[temp+ *lpdest*256];
+					*lpdest = vid_alphamap[temp + *lpdest*256];
 				}
 				lpdest++;
 				lzi += r_zistepx;
 				lpz++;
-				llight += r_lstepx;
+				for(i=0; i<3; i++)
+					llight[i] += r_lstepx[i];
 				lptex += a_ststepxwhole;
 				lsfrac += a_sstepxfrac;
 				lptex += lsfrac >> SHIFT16XYZ;
@@ -546,7 +548,7 @@ R_PolysetDrawSpans8_66(const entity_t *currententity, spanpackage_t *pspanpackag
 	pixel_t		*lpdest;
 	pixel_t		*lptex;
 	int		lsfrac, ltfrac;
-	int		llight;
+	light3_t	llight;
 	zvalue_t	lzi;
 	zvalue_t	*lpz;
 
@@ -576,14 +578,16 @@ R_PolysetDrawSpans8_66(const entity_t *currententity, spanpackage_t *pspanpackag
 			lptex = pspanpackage->ptex;
 			lsfrac = pspanpackage->sfrac;
 			ltfrac = pspanpackage->tfrac;
-			llight = pspanpackage->light;
+			memcpy(llight, pspanpackage->light, sizeof(light3_t));
 			lzi = pspanpackage->zi;
 
 			do
 			{
+				int i;
+
 				if ((lzi >> SHIFT16XYZ) >= *lpz)
 				{
-					int temp = vid_colormap[*lptex + ( llight & 0xFF00 )];
+					int temp = R_ApplyLight(*lptex, llight);
 
 					*lpdest = vid_alphamap[temp*256 + *lpdest];
 					*lpz = lzi >> SHIFT16XYZ;
@@ -592,7 +596,8 @@ R_PolysetDrawSpans8_66(const entity_t *currententity, spanpackage_t *pspanpackag
 				lpdest++;
 				lzi += r_zistepx;
 				lpz++;
-				llight += r_lstepx;
+				for(i=0; i<3; i++)
+					llight[i] += r_lstepx[i];
 				lptex += a_ststepxwhole;
 				lsfrac += a_sstepxfrac;
 				lptex += lsfrac >> SHIFT16XYZ;
@@ -700,7 +705,7 @@ R_PolysetDrawSpans8_Opaque (const entity_t *currententity, spanpackage_t *pspanp
 			int		lsfrac, ltfrac;
 			pixel_t		*lpdest;
 			pixel_t		*lptex;
-			int		llight;
+			light3_t	llight;
 			zvalue_t	lzi;
 			zvalue_t	*lpz;
 			int		pos_shift = (pspanpackage->v * vid_buffer_width) + pspanpackage->u;
@@ -712,17 +717,19 @@ R_PolysetDrawSpans8_Opaque (const entity_t *currententity, spanpackage_t *pspanp
 			lptex = pspanpackage->ptex;
 			lsfrac = pspanpackage->sfrac;
 			ltfrac = pspanpackage->tfrac;
-			llight = pspanpackage->light;
+			memcpy(llight, pspanpackage->light, sizeof(light3_t));
 			lzi = pspanpackage->zi;
 
 			do
 			{
+				int i;
+
 				if ((lzi >> SHIFT16XYZ) >= *lpz)
 				{
 					if(r_newrefdef.rdflags & RDF_IRGOGGLES && currententity->flags & RF_IR_VISIBLE)
-						*lpdest = ((byte *)vid_colormap)[irtable[*lptex]];
+						*lpdest = vid_colormap[irtable[*lptex]];
 					else
-						*lpdest = ((byte *)vid_colormap)[*lptex + (llight & 0xFF00)];
+						*lpdest = R_ApplyLight(*lptex, llight);
 
 					*lpz = lzi >> SHIFT16XYZ;
 					zdamaged = true;
@@ -730,7 +737,8 @@ R_PolysetDrawSpans8_Opaque (const entity_t *currententity, spanpackage_t *pspanp
 				lpdest++;
 				lzi += r_zistepx;
 				lpz++;
-				llight += r_lstepx;
+				for(i=0; i<3; i++)
+					llight[i] += r_lstepx[i];
 				lptex += a_ststepxwhole;
 				lsfrac += a_sstepxfrac;
 				lptex += lsfrac >> SHIFT16XYZ;
@@ -766,8 +774,9 @@ static void
 R_RasterizeAliasPolySmooth(const entity_t *currententity)
 {
 	int	initialleftheight, initialrightheight;
-	int	*plefttop, *prighttop, *pleftbottom, *prightbottom;
-	int	working_lstepx, originalcount;
+	compactvert_t	*plefttop, *prighttop, *pleftbottom, *prightbottom;
+	light3_t	working_lstepx;
+	int originalcount;
 	int	u, v;
 	pixel_t	*d_ptex;
 
@@ -777,8 +786,8 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 	pleftbottom = pedgetable->pleftedgevert1;
 	prightbottom = pedgetable->prightedgevert1;
 
-	initialleftheight = pleftbottom[1] - plefttop[1];
-	initialrightheight = prightbottom[1] - prighttop[1];
+	initialleftheight = pleftbottom->v - plefttop->v;
+	initialrightheight = prightbottom->v - prighttop->v;
 
 	//
 	// set the s, t, and light gradients, which are consistent across the triangle
@@ -794,18 +803,18 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 	//
 	d_pedgespanpackage = triangle_spans;
 
-	u = plefttop[0];
-	v = plefttop[1];
-	d_aspancount = plefttop[0] - prighttop[0];
+	u = plefttop->u;
+	v = plefttop->v;
+	d_aspancount = plefttop->u - prighttop->u;
 
-	d_ptex = (byte *)r_affinetridesc.pskin + (plefttop[2] >> SHIFT16XYZ) +
-			(plefttop[3] >> SHIFT16XYZ) * r_affinetridesc.skinwidth;
+	d_ptex = r_affinetridesc.pskin + (plefttop->s >> SHIFT16XYZ) +
+			(plefttop->t >> SHIFT16XYZ) * r_affinetridesc.skinwidth;
 	{
-		d_sfrac = plefttop[2] & 0xFFFF;
-		d_tfrac = plefttop[3] & 0xFFFF;
+		d_sfrac = plefttop->s & 0xFFFF;
+		d_tfrac = plefttop->t & 0xFFFF;
 	}
-	d_light = plefttop[4];
-	d_zi = plefttop[5];
+	memcpy(d_light, plefttop->l, sizeof(light3_t));
+	d_zi = plefttop->zi;
 
 	if (initialleftheight == 1)
 	{
@@ -814,8 +823,10 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 	}
 	else
 	{
-		R_PolysetSetUpForLineScan(plefttop[0], plefttop[1],
-					  pleftbottom[0], pleftbottom[1]);
+		int i;
+
+		R_PolysetSetUpForLineScan(plefttop->u, plefttop->v,
+					  pleftbottom->u, pleftbottom->v);
 
 		// TODO: can reuse partial expressions here
 
@@ -823,9 +834,12 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 		// underflow (sort of turning the floor () we did in the gradient calcs into
 		// ceil (), but plus a little bit)
 		if (ubasestep < 0)
-			working_lstepx = r_lstepx - 1;
+		{
+			for(i=0; i<3; i++)
+				working_lstepx[i] = r_lstepx[i] - 1;
+		}
 		else
-			working_lstepx = r_lstepx;
+			memcpy(working_lstepx, r_lstepx, sizeof(light3_t));
 
 		d_ptexbasestep = ((r_sstepy + r_sstepx * ubasestep) >> SHIFT16XYZ) +
 				((r_tstepy + r_tstepx * ubasestep) >> SHIFT16XYZ) *
@@ -834,7 +848,9 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 		d_sfracbasestep = (r_sstepy + r_sstepx * ubasestep) & 0xFFFF;
 		d_tfracbasestep = (r_tstepy + r_tstepx * ubasestep) & 0xFFFF;
 
-		d_lightbasestep = r_lstepy + working_lstepx * ubasestep;
+		for(i=0; i<3; i++)
+			d_lightbasestep[i] = r_lstepy[i] + working_lstepx[i] * ubasestep;
+
 		d_zibasestep = r_zistepy + r_zistepx * ubasestep;
 
 		d_ptexextrastep = ((r_sstepy + r_sstepx * (ubasestep + 1)) >> SHIFT16XYZ) +
@@ -844,7 +860,9 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 		d_sfracextrastep = (r_sstepy + r_sstepx*(ubasestep + 1)) & 0xFFFF;
 		d_tfracextrastep = (r_tstepy + r_tstepx*(ubasestep + 1)) & 0xFFFF;
 
-		d_lightextrastep = d_lightbasestep + working_lstepx;
+		for(i=0; i<3; i++)
+			d_lightextrastep[i] = d_lightbasestep[i] + working_lstepx[i];
+
 		d_ziextrastep = d_zibasestep + r_zistepx;
 
 		R_PolysetScanLeftEdge_C(initialleftheight, d_ptex, u, v);
@@ -860,18 +878,18 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 		plefttop = pleftbottom;
 		pleftbottom = pedgetable->pleftedgevert2;
 
-		height = pleftbottom[1] - plefttop[1];
+		height = pleftbottom->v - plefttop->v;
 
 		// TODO: make this a function; modularize this function in general
-		u = plefttop[0];
-		v = plefttop[1];
-		d_aspancount = plefttop[0] - prighttop[0];
-		d_ptex = (byte *)r_affinetridesc.pskin + (plefttop[2] >> SHIFT16XYZ) +
-				(plefttop[3] >> SHIFT16XYZ) * r_affinetridesc.skinwidth;
+		u = plefttop->u;
+		v = plefttop->v;
+		d_aspancount = plefttop->u - prighttop->u;
+		d_ptex = r_affinetridesc.pskin + (plefttop->s >> SHIFT16XYZ) +
+				(plefttop->t >> SHIFT16XYZ) * r_affinetridesc.skinwidth;
 		d_sfrac = 0;
 		d_tfrac = 0;
-		d_light = plefttop[4];
-		d_zi = plefttop[5];
+		memcpy(d_light, plefttop->l, sizeof(light3_t));
+		d_zi = plefttop->zi;
 
 		if (height == 1)
 		{
@@ -880,13 +898,18 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 		}
 		else
 		{
-			R_PolysetSetUpForLineScan(plefttop[0], plefttop[1],
-								  pleftbottom[0], pleftbottom[1]);
+			int i;
+
+			R_PolysetSetUpForLineScan(plefttop->u, plefttop->v,
+								  pleftbottom->u, pleftbottom->v);
 
 			if (ubasestep < 0)
-				working_lstepx = r_lstepx - 1;
+			{
+				for(i=0; i<3; i++)
+					working_lstepx[i] = r_lstepx[i] - 1;
+			}
 			else
-				working_lstepx = r_lstepx;
+				memcpy(working_lstepx, r_lstepx, sizeof(light3_t));
 
 			d_ptexbasestep = ((r_sstepy + r_sstepx * ubasestep) >> SHIFT16XYZ) +
 					((r_tstepy + r_tstepx * ubasestep) >> SHIFT16XYZ) *
@@ -895,7 +918,9 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 			d_sfracbasestep = (r_sstepy + r_sstepx * ubasestep) & 0xFFFF;
 			d_tfracbasestep = (r_tstepy + r_tstepx * ubasestep) & 0xFFFF;
 
-			d_lightbasestep = r_lstepy + working_lstepx * ubasestep;
+			for(i=0; i<3; i++)
+				d_lightbasestep[i] = r_lstepy[i] + working_lstepx[i] * ubasestep;
+
 			d_zibasestep = r_zistepy + r_zistepx * ubasestep;
 
 			d_ptexextrastep = ((r_sstepy + r_sstepx * (ubasestep + 1)) >> SHIFT16XYZ) +
@@ -905,7 +930,8 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 			d_sfracextrastep = (r_sstepy+r_sstepx*(ubasestep + 1)) & 0xFFFF;
 			d_tfracextrastep = (r_tstepy+r_tstepx*(ubasestep + 1)) & 0xFFFF;
 
-			d_lightextrastep = d_lightbasestep + working_lstepx;
+			for(i=0; i<3; i++)
+				d_lightextrastep[i] = d_lightbasestep[i] + working_lstepx[i];
 			d_ziextrastep = d_zibasestep + r_zistepx;
 
 			R_PolysetScanLeftEdge_C(height, d_ptex, u, v);
@@ -914,8 +940,8 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 
 	// scan out the top (and possibly only) part of the right edge, updating the
 	// count field
-	R_PolysetSetUpForLineScan(prighttop[0], prighttop[1],
-						  prightbottom[0], prightbottom[1]);
+	R_PolysetSetUpForLineScan(prighttop->u, prighttop->v,
+						  prightbottom->u, prightbottom->v);
 	d_aspancount = 0;
 	if ((triangle_spans + initialrightheight) >= triangles_max)
 	{
@@ -936,15 +962,15 @@ R_RasterizeAliasPolySmooth(const entity_t *currententity)
 		pstart = triangle_spans + initialrightheight;
 		pstart->count = originalcount;
 
-		d_aspancount = prightbottom[0] - prighttop[0];
+		d_aspancount = prightbottom->u - prighttop->u;
 
 		prighttop = prightbottom;
 		prightbottom = pedgetable->prightedgevert2;
 
-		height = prightbottom[1] - prighttop[1];
+		height = prightbottom->v - prighttop->v;
 
-		R_PolysetSetUpForLineScan(prighttop[0], prighttop[1],
-							  prightbottom[0], prightbottom[1]);
+		R_PolysetSetUpForLineScan(prighttop->u, prighttop->v,
+							  prightbottom->u, prightbottom->v);
 
 		if ((triangle_spans + initialrightheight + height) >= triangles_max)
 		{
@@ -975,11 +1001,11 @@ R_PolysetSetEdgeTable (void)
 	// determine which edges are right & left, and the order in which
 	// to rasterize them
 	//
-	if (r_p0[1] >= r_p1[1])
+	if (r_p0.v >= r_p1.v)
 	{
-		if (r_p0[1] == r_p1[1])
+		if (r_p0.v == r_p1.v)
 		{
-			if (r_p0[1] < r_p2[1])
+			if (r_p0.v < r_p2.v)
 				pedgetable = &edgetables[2];
 			else
 				pedgetable = &edgetables[5];
@@ -992,7 +1018,7 @@ R_PolysetSetEdgeTable (void)
 		}
 	}
 
-	if (r_p0[1] == r_p2[1])
+	if (r_p0.v == r_p2.v)
 	{
 		if (edgetableindex)
 			pedgetable = &edgetables[8];
@@ -1001,7 +1027,7 @@ R_PolysetSetEdgeTable (void)
 
 		return;
 	}
-	else if (r_p1[1] == r_p2[1])
+	else if (r_p1.v == r_p2.v)
 	{
 		if (edgetableindex)
 			pedgetable = &edgetables[10];
@@ -1011,10 +1037,10 @@ R_PolysetSetEdgeTable (void)
 		return;
 	}
 
-	if (r_p0[1] > r_p2[1])
+	if (r_p0.v > r_p2.v)
 		edgetableindex += 2;
 
-	if (r_p1[1] > r_p2[1])
+	if (r_p1.v > r_p2.v)
 		edgetableindex += 4;
 
 	pedgetable = &edgetables[edgetableindex];
