@@ -22,15 +22,10 @@
  * =======================================================================
  */
 
-#ifdef OGG
-
 #ifndef CL_SOUND_VORBIS_H
 #define CL_SOUND_VORBIS_H
 
-/* The OGG codec can return the samples in a number
- * of different formats, we use the standard signed
- * short format. */
-#define OGG_SAMPLEWIDTH 2
+#include "local.h"
 
 typedef enum
 {
@@ -41,10 +36,12 @@ typedef enum
 
 void OGG_InitTrackList(void);
 void OGG_Init(void);
-void OGG_PlayTrack(int track);
+void OGG_PlayTrack(int trackNo);
+void OGG_RecoverState(void);
+void OGG_SaveState(void);
 void OGG_Shutdown(void);
 void OGG_Stop(void);
 void OGG_Stream(void);
+void OGG_LoadAsWav(char *filename, wavinfo_t *info, void **buffer);
 
 #endif
-#endif
