@@ -72,6 +72,8 @@ cvar_t *s_ambient;
 cvar_t* s_underwater;
 cvar_t* s_underwater_gain_hf;
 cvar_t* s_doppler;
+cvar_t* s_occlusion_strength;
+cvar_t* s_reverb_preset;
 cvar_t* s_ps_sorting;
 
 channel_t channels[MAX_CHANNELS];
@@ -1107,34 +1109,18 @@ S_StartSound(vec3_t origin, int entnum, int entchannel, sfx_t *sfx,
 
 	if (sfx->name[0])
 	{
-		vec3_t orientation, direction;
-		vec_t distance_direction;
-		int dir_x, dir_y, dir_z;
-		int effect_duration = 0;
-		int effect_volume = -1;
+		vec3_t direction = {0};
+		unsigned int effect_duration = 0;
+		unsigned short int effect_volume = 0;
 
-		VectorSubtract(listener_forward, listener_up, orientation);
-
-		// with !fixed we have all sounds related directly to player,
+		// with !ps->fixed we have all sounds related directly to player,
 		// e.g. players fire, pain, menu
-		if (!ps->fixed_origin)
-		{
-			VectorCopy(orientation, direction);
-			distance_direction = 0;
-		}
-		else
+		// else, they come from the environment
+		if (ps->fixed_origin)
 		{
 			VectorSubtract(listener_origin, ps->origin, direction);
-			distance_direction = VectorLength(direction);
 		}
 
-		VectorNormalize(direction);
-		VectorNormalize(orientation);
-
-		dir_x = 16 * orientation[0] * direction[0];
-		dir_y = 16 * orientation[1] * direction[1];
-		dir_z = 16 * orientation[2] * direction[2];
-
 		if (sfx->cache)
 		{
 			effect_duration = sfx->cache->length;
@@ -1144,16 +1130,19 @@ S_StartSound(vec3_t origin, int entnum, int entchannel, sfx_t *sfx,
 				effect_duration /= 2;
 			}
 
-			/* sound near player has 16 points */
-			effect_volume = sfx->cache->volume / 16;
+			// The following may be ugly: cache length in SDL is much, much bigger
+			// than the one in OpenAL, so much that it's definitely not in ms.
+			// If that changes in the future, this must be removed.
+			if (sound_started == SS_SDL)
+			{
+				effect_duration /= 45;
+			}
+
+			effect_volume = sfx->cache->volume;
 		}
 
-		Haptic_Feedback(
-			sfx->name, (16 - distance_direction / 32) * effect_volume,
-			effect_duration,
-			sfx->cache->begin, sfx->cache->end,
-			sfx->cache->attack, sfx->cache->fade,
-			dir_x, dir_y, dir_z);
+		Controller_Rumble(sfx->name, direction, !ps->fixed_origin,
+			effect_duration, effect_volume);
 	}
 
 	ps->entnum = entnum;
@@ -1552,6 +1541,9 @@ S_Init(void)
 	s_underwater_gain_hf = Cvar_Get("s_underwater_gain_hf", "0.25", CVAR_ARCHIVE);
 	s_doppler = Cvar_Get("s_doppler", "0", CVAR_ARCHIVE);
 	s_ps_sorting = Cvar_Get("s_ps_sorting", "1", CVAR_ARCHIVE);
+	/* Reverb and occlusion is fully disabled by default */
+	s_reverb_preset = Cvar_Get("s_reverb_preset", "-1", CVAR_ARCHIVE);
+	s_occlusion_strength = Cvar_Get("s_occlusion_strength", "0", CVAR_ARCHIVE);
 
 	Cmd_AddCommand("play", S_Play);
 	Cmd_AddCommand("stopsound", S_StopAllSounds);
