@@ -28,10 +28,10 @@
 
 extern cvar_t *maxclients;
 
-qboolean enemy_vis;
-qboolean enemy_infront;
-int enemy_range;
-float enemy_yaw;
+static qboolean enemy_vis;
+static qboolean enemy_infront;
+static int enemy_range;
+static float enemy_yaw;
 
 qboolean FindTarget(edict_t *self);
 qboolean ai_checkattack(edict_t *self);
