@@ -55,6 +55,7 @@ cvar_t *maxentities;
 cvar_t *g_select_empty;
 cvar_t *dedicated;
 cvar_t *g_footsteps;
+cvar_t *g_monsterfootsteps;
 cvar_t *g_fix_triggered;
 cvar_t *g_commanderbody_nogod;
 
@@ -88,19 +89,6 @@ cvar_t *gib_on;
 cvar_t *aimfix;
 cvar_t *g_machinegun_norecoil;
 
-void SpawnEntities(char *mapname, char *entities, char *spawnpoint);
-void ClientThink(edict_t *ent, usercmd_t *cmd);
-qboolean ClientConnect(edict_t *ent, char *userinfo);
-void ClientUserinfoChanged(edict_t *ent, char *userinfo);
-void ClientDisconnect(edict_t *ent);
-void ClientBegin(edict_t *ent);
-void ClientCommand(edict_t *ent);
-void RunEntity(edict_t *ent);
-void WriteGame(char *filename, qboolean autosave);
-void ReadGame(char *filename);
-void WriteLevel(char *filename);
-void ReadLevel(char *filename);
-void InitGame(void);
 void G_RunFrame(void);
 
 /* =================================================================== */
@@ -114,6 +102,41 @@ ShutdownGame(void)
 	gi.FreeTags(TAG_GAME);
 }
 
+/*
+ * convert function declarations to correct one
+ * (warning like from incompatible pointer type)
+ * little bit better than cast function before set
+ */
+static void
+ReadLevel_f(char *filename)
+{
+	ReadLevel(filename);
+}
+
+static void
+WriteLevel_f(char *filename)
+{
+	WriteLevel(filename);
+}
+
+static void
+ReadGame_f(char *filename)
+{
+	ReadGame(filename);
+}
+
+static void
+WriteGame_f(char *filename, qboolean autosave)
+{
+	WriteGame(filename, autosave);
+}
+
+static void
+SpawnEntities_f(char *mapname, char *entities, char *spawnpoint)
+{
+	SpawnEntities(mapname, entities, spawnpoint);
+}
+
 /*
  * Returns a pointer to the structure
  * with all entry points and global
@@ -127,12 +150,12 @@ GetGameAPI(game_import_t *import)
 	globals.apiversion = GAME_API_VERSION;
 	globals.Init = InitGame;
 	globals.Shutdown = ShutdownGame;
-	globals.SpawnEntities = SpawnEntities;
+	globals.SpawnEntities = SpawnEntities_f;
 
-	globals.WriteGame = WriteGame;
-	globals.ReadGame = ReadGame;
-	globals.WriteLevel = WriteLevel;
-	globals.ReadLevel = ReadLevel;
+	globals.WriteGame = WriteGame_f;
+	globals.ReadGame = ReadGame_f;
+	globals.WriteLevel = WriteLevel_f;
+	globals.ReadLevel = ReadLevel_f;
 
 	globals.ClientThink = ClientThink;
 	globals.ClientConnect = ClientConnect;
