@@ -259,22 +259,6 @@ SP_CreateUnnamedSpawn(edict_t *self)
 		}
 	}
 
-	/* waste3 */
-    if (Q_stricmp(level.mapname, "waste3") == 0)
-	{
-		if (Q_stricmp(self->targetname, "waste2") == 0)
-		{
-			spot->classname = self->classname;
-			spot->s.origin[0] = self->s.origin[0];
-			spot->s.origin[1] = self->s.origin[1];
-			spot->s.origin[2] = self->s.origin[2];
-			spot->s.angles[1] = self->s.angles[1];
-			spot->targetname = NULL;
-
-			return;
-		}
-	}
-
 	/* city3 */
     if (Q_stricmp(level.mapname, "city2") == 0)
 	{
@@ -392,7 +376,7 @@ SP_info_player_coop(edict_t *self)
  * roll as well as yaw.  'pitch yaw roll'
  */
 void
-SP_info_player_intermission(void)
+SP_info_player_intermission(edict_t *self)
 {
 	/* Thus function cannot be removed
 	 * since the info_player_intermission
@@ -908,9 +892,8 @@ player_die(edict_t *self, edict_t *inflictor, edict_t *attacker,
 
 	if (self->health < -40)
 	{
-		/* gib */
-		gi.sound(self, CHAN_BODY, gi.soundindex(
-						"misc/udeath.wav"), 1, ATTN_NORM, 0);
+		/* gib (sound is played at end of server frame) */
+		self->sounds = gi.soundindex("misc/udeath.wav");
 
 		for (n = 0; n < 4; n++)
 		{
@@ -958,8 +941,12 @@ player_die(edict_t *self, edict_t *inflictor, edict_t *attacker,
 				}
 			}
 
-			gi.sound(self, CHAN_VOICE, gi.soundindex(va("*death%i.wav",
-							(randk() % 4) + 1)), 1, ATTN_NORM, 0);
+			/* sound is played at end of server frame */
+			if (!self->sounds)
+			{
+				self->sounds = gi.soundindex(va("*death%i.wav",
+								(randk() % 4) + 1));
+			}
 		}
 	}
 
@@ -2142,7 +2129,7 @@ ClientDisconnect(edict_t *ent)
 
 /* ============================================================== */
 
-edict_t *pm_passent;
+static edict_t *pm_passent;
 
 /*
  * pmove doesn't need to know
