@@ -65,13 +65,13 @@
  */
 
 #include "../header/local.h"
-
+#include "savegame.h"
 /*
  * When ever the savegame version is changed, q2 will refuse to
  * load older savegames. This should be bumped if the files
  * in tables/ are changed, otherwise strange things may happen.
  */
-#define SAVEGAMEVER "YQ2-4"
+#define SAVEGAMEVER "YQ2-5"
 
 #ifndef BUILD_DATE
 #define BUILD_DATE __DATE__
@@ -120,36 +120,6 @@
  #define ARCH_1 "unknown"
 #endif
 
-/*
- * Connects a human readable
- * function signature with
- * the corresponding pointer
- */
-typedef struct
-{
-	char *funcStr;
-	byte *funcPtr;
-} functionList_t;
-
-/*
- * Connects a human readable
- * mmove_t string with the
- * corresponding pointer
- * */
-typedef struct
-{
-	char	*mmoveStr;
-	mmove_t *mmovePtr;
-} mmoveList_t;
-
-typedef struct
-{
-    char ver[32];
-    char game[32];
-    char os[32];
-    char arch[32];
-} savegameHeader_t;
-
 /* ========================================================= */
 
 /*
@@ -164,7 +134,7 @@ typedef struct
  * to each of the functions
  * prototyped above.
  */
-functionList_t functionList[] = {
+static functionList_t functionList[] = {
 	#include "tables/gamefunc_list.h"
 };
 
@@ -181,12 +151,12 @@ functionList_t functionList[] = {
  * functions prototyped
  * above.
  */
-mmoveList_t mmoveList[] = {
+static mmoveList_t mmoveList[] = {
 	#include "tables/gamemmove_list.h"
 };
 
 /*
- * Fields to be saved
+ * Fields to be saved (used in g_spawn.c)
  */
 field_t fields[] = {
 	#include "tables/fields.h"
@@ -196,7 +166,7 @@ field_t fields[] = {
  * Level fields to
  * be saved
  */
-field_t levelfields[] = {
+static field_t levelfields[] = {
 	#include "tables/levelfields.h"
 };
 
@@ -204,7 +174,7 @@ field_t levelfields[] = {
  * Client fields to
  * be saved
  */
-field_t clientfields[] = {
+static field_t clientfields[] = {
 	#include "tables/clientfields.h"
 };
 
@@ -245,6 +215,7 @@ InitGame(void)
 	skill = gi.cvar("skill", "1", CVAR_LATCH);
 	maxentities = gi.cvar("maxentities", "1024", CVAR_LATCH);
 	g_footsteps = gi.cvar("g_footsteps", "1", CVAR_ARCHIVE);
+	g_monsterfootsteps = gi.cvar("g_monsterfootsteps", "0", CVAR_ARCHIVE);
 	g_fix_triggered = gi.cvar ("g_fix_triggered", "0", 0);
 	g_commanderbody_nogod = gi.cvar("g_commanderbody_nogod", "0", CVAR_ARCHIVE);
 
@@ -856,6 +827,7 @@ ReadGame(const char *filename)
 		{"YQ2-2", 2},
 		{"YQ2-3", 3},
 		{"YQ2-4", 4},
+		{"YQ2-5", 5},
 	};
 
 	for (i=0; i < sizeof(version_mappings)/sizeof(version_mappings[0]); ++i)
