@@ -241,6 +241,7 @@
 {"SP_monster_soldier", (byte *)SP_monster_soldier},
 {"SP_monster_soldier_light", (byte *)SP_monster_soldier_light},
 {"SP_monster_soldier_x", (byte *)SP_monster_soldier_x},
+{"soldier_footstep", (byte *)soldier_footstep},
 {"soldier_die", (byte *)soldier_die},
 {"soldier_dead", (byte *)soldier_dead},
 {"soldier_fire7", (byte *)soldier_fire7},
@@ -327,6 +328,7 @@
 {"SV_movestep", (byte *)SV_movestep},
 {"M_CheckBottom", (byte *)M_CheckBottom},
 {"SP_monster_medic", (byte *)SP_monster_medic},
+{"medic_footstep", (byte *)medic_footstep},
 {"medic_checkattack", (byte *)medic_checkattack},
 {"medic_attack", (byte *)medic_attack},
 {"medic_hook_retract", (byte *)medic_hook_retract},
@@ -349,6 +351,7 @@
 {"medic_idle", (byte *)medic_idle},
 {"medic_FindDeadMonster", (byte *)medic_FindDeadMonster},
 {"SP_misc_insane", (byte *)SP_misc_insane},
+{"insane_footstep", (byte *)insane_footstep},
 {"insane_die", (byte *)insane_die},
 {"insane_dead", (byte *)insane_dead},
 {"insane_stand", (byte *)insane_stand},
@@ -364,6 +367,7 @@
 {"insane_shake", (byte *)insane_shake},
 {"insane_fist", (byte *)insane_fist},
 {"SP_monster_infantry", (byte *)SP_monster_infantry},
+{"infantry_footstep", (byte *)infantry_footstep},
 {"infantry_attack", (byte *)infantry_attack},
 {"infantry_smack", (byte *)infantry_smack},
 {"infantry_swing", (byte *)infantry_swing},
@@ -397,6 +401,7 @@
 {"hover_search", (byte *)hover_search},
 {"hover_sight", (byte *)hover_sight},
 {"SP_monster_gunner", (byte *)SP_monster_gunner},
+{"gunner_footstep", (byte *)gunner_footstep},
 {"gunner_refire_chain", (byte *)gunner_refire_chain},
 {"gunner_fire_chain", (byte *)gunner_fire_chain},
 {"gunner_attack", (byte *)gunner_attack},
@@ -419,6 +424,7 @@
 {"gunner_sight", (byte *)gunner_sight},
 {"gunner_idlesound", (byte *)gunner_idlesound},
 {"SP_monster_gladiator", (byte *)SP_monster_gladiator},
+{"gladiator_footstep", (byte *)gladiator_footstep},
 {"gladiator_die", (byte *)gladiator_die},
 {"gladiator_dead", (byte *)gladiator_dead},
 {"gladiator_pain", (byte *)gladiator_pain},
@@ -483,6 +489,7 @@
 {"flipper_run_loop", (byte *)flipper_run_loop},
 {"flipper_stand", (byte *)flipper_stand},
 {"SP_monster_chick", (byte *)SP_monster_chick},
+{"chick_footstep", (byte *)chick_footstep},
 {"chick_sight", (byte *)chick_sight},
 {"chick_attack", (byte *)chick_attack},
 {"chick_melee", (byte *)chick_melee},
@@ -507,6 +514,7 @@
 {"chick_fidget", (byte *)chick_fidget},
 {"ChickMoan", (byte *)ChickMoan},
 {"SP_monster_brain", (byte *)SP_monster_brain},
+{"brain_footstep", (byte *)brain_footstep},
 {"brain_die", (byte *)brain_die},
 {"brain_dead", (byte *)brain_dead},
 {"brain_pain", (byte *)brain_pain},
@@ -594,6 +602,7 @@
 {"Boss2Rocket", (byte *)Boss2Rocket},
 {"boss2_search", (byte *)boss2_search},
 {"SP_monster_berserk", (byte *)SP_monster_berserk},
+{"berserk_footstep", (byte *)berserk_footstep},
 {"berserk_die", (byte *)berserk_die},
 {"berserk_dead", (byte *)berserk_dead},
 {"berserk_pain", (byte *)berserk_pain},
