@@ -374,7 +374,7 @@ SV_RunGameFrame(void)
 }
 
 void
-SV_Frame(int msec)
+SV_Frame(int usec)
 {
 #ifndef DEDICATED_ONLY
 	time_before_game = time_after_game = 0;
@@ -386,7 +386,7 @@ SV_Frame(int msec)
 		return;
 	}
 
-	svs.realtime += msec / 1000;
+	svs.realtime += usec / 1000;
 
 	/* keep the random time dependent */
 	randk();
@@ -584,8 +584,9 @@ SV_Init(void)
 
 	rcon_password = Cvar_Get("rcon_password", "", 0);
 	Cvar_Get("skill", "1", 0);
-	Cvar_Get("deathmatch", "0", CVAR_LATCH);
-	Cvar_Get("coop", "0", CVAR_LATCH);
+	Cvar_Get("singleplayer", "0", CVAR_SERVERINFO | CVAR_LATCH);
+	Cvar_Get("deathmatch", "0", CVAR_SERVERINFO | CVAR_LATCH);
+	Cvar_Get("coop", "0", CVAR_SERVERINFO | CVAR_LATCH);
 	Cvar_Get("dmflags", va("%i", DF_INSTANT_ITEMS), CVAR_SERVERINFO);
 	Cvar_Get("fraglimit", "0", CVAR_SERVERINFO);
 	Cvar_Get("timelimit", "0", CVAR_SERVERINFO);
